@@ -680,3 +680,44 @@ class OpenstackClient(OpenstackBase):
             subnet_list = self.neutron_client.list_subnets(id=subnet_id, ip_version=4)["subnets"]
             if len(subnet_list) > 0:
                 return subnet_list[0]["gateway_ip"]
+
+    def get_servers_with_net_info(self):
+        """
+        list servers and add net_info to server object.
+        server.net_info = {
+        u'RCP-1234-internal-net': {
+            'mac': 'fa:16:3e:38:b4:d5',
+            'subnets': {
+                u'58ec5872-a3eb-4736-bde7-11dce2e6d904': {
+                    'ip_version': 4, 'subnet_name': u'RCP-1234-internal-subnet',
+                    'cidr': u'192.168.1.0/24', 'ip_address': u'192.168.1.12',
+                    'allocation_pools': [{u'start': u'192.168.1.2', u'end': u'192.168.1.205'}]}},
+                    'allowed_address_pairs': [{"ip_address": "192.168.1.0/24", "mac_address": "fa:16:3e:95:6a:d8"}]}}
+        :return:
+        """
+        servers = self.nova_client.servers.list()
+        result = []
+        for server in servers:
+            if server.tenant_id == self.project_id:
+                server.net_info = {}
+                for net_name, subnet in server.addresses.items():
+                    port = self.neutron_client.list_ports(mac_address=subnet[0]["OS-EXT-IPS-MAC:mac_addr"]).values()[0][0]
+                    server.net_info[net_name] = {"mac": port["mac_address"],
+                                                 "subnets": {}}
+                    for i in port["fixed_ips"]:
+                        subnet = self.neutron_client.list_subnets(id=i["subnet_id"]).values()[0][0]
+                        server.net_info[net_name]["subnets"].update(
+                            {
+                                i["subnet_id"]: {
+                                    "ip_address": i["ip_address"],
+                                    "cidr": subnet["cidr"],
+                                    "allocation_pools": subnet["allocation_pools"],
+                                    "subnet_name": subnet["name"],
+                                    "ip_version": subnet["ip_version"]
+                                }
+                            }
+                        )
+                result.append(server)
+        return result
+
+
